@@ -15,11 +15,11 @@
 #' @return A `lcModel` object representing the fitted model.
 #' @examples
 #' data(latrendData)
-#' model <- latrend(lcMethodKML("Y", id = "Id", time = "Time"), data = latrendData)
+#' model <- latrend(lcMethodLMKM(Y ~ Time, id = "Id", time = "Time"), data = latrendData)
 #'
-#' model <- latrend("lcMethodKML", response = "Y", id = "Id", time = "Time", data = latrendData)
+#' model <- latrend("lcMethodLMKM", formula = Y ~ Time, id = "Id", time = "Time", data = latrendData)
 #'
-#' method <- lcMethodKML("Y", id = "Id", time = "Time")
+#' method <- lcMethodLMKM(Y ~ Time, id = "Id", time = "Time")
 #' model <- latrend(method, data = latrendData, nClusters = 3)
 #'
 #' model <- latrend(method, data = latrendData, nClusters = 3, seed = 1)
@@ -409,7 +409,7 @@ latrendBatch = function(
   # transform data
   enter(verbose, sprintf('Checking and transforming the data format for %d datasets.', nData), suffix = '', level = verboseLevels$fine)
   allData = lapply(allDataOpts, eval, envir = envir)
-  allModelData = mapply(
+  allModelData = Map(
     function(data, method) {
       trajectories(
         data,
@@ -420,8 +420,7 @@ latrendBatch = function(
       )
     },
     allData,
-    allMethods,
-    SIMPLIFY = FALSE
+    allMethods
   )
 
   assert_that(
@@ -433,7 +432,7 @@ latrendBatch = function(
 
   # validate methods on data
   enter(verbose, sprintf('Validating methods against the datasets (%d checks).', nModels), level = verboseLevels$fine, suffix = '')
-  mapply(validate, allMethods, allModelData, SIMPLIFY = FALSE)
+  Map(validate, allMethods, allModelData)
   exit(verbose, level = verboseLevels$finest)
 
   # seeds
@@ -444,7 +443,7 @@ latrendBatch = function(
 
   # update methods that don't have a seed argument
   seedMask = !vapply(allMethods, hasName, 'seed', FUN.VALUE = TRUE)
-  allMethods[seedMask] = mapply(
+  allMethods[seedMask] = Map(
     function(method, seed) update(method, seed = seed, .eval = TRUE),
     allMethods[seedMask],
     allSeeds[seedMask]
@@ -595,7 +594,7 @@ latrendBoot = function(
   assert_that(has_name(data, id))
 
   # fit models
-  methods = replicate(samples, method)
+  methods = replicate(samples, method, simplify = FALSE)
 
   dataCalls = lapply(sampleSeeds, function(s)
     enquote(substitute(
@@ -640,9 +639,12 @@ latrendBoot = function(
 #' @examples
 #' data(latrendData)
 #' method <- lcMethodLMKM(Y ~ Time, id = "Id", time = "Time")
-#' model <- latrendCV(method, latrendData, folds = 5)
 #'
-#' model <- latrendCV(method, subset(latrendData, Time < .5), folds = 5, seed = 1)
+#' if (require("caret")) {
+#'   model <- latrendCV(method, latrendData, folds = 5)
+#'
+#'   model <- latrendCV(method, subset(latrendData, Time < .5), folds = 5, seed = 1)
+#' }
 #' @family longitudinal cluster fit functions
 #' @family validation methods
 latrendCV = function(
@@ -655,6 +657,8 @@ latrendCV = function(
   envir = NULL,
   verbose = getOption('latrend.verbose')
 ) {
+  .checkPackageInstalled('caret')
+
   assert_that(!missing(data), msg = 'data must be specified')
   assert_that(is.data.frame(data), msg = 'data must be data.frame')
   assert_that(is.count(folds))
@@ -712,9 +716,12 @@ latrendCV = function(
 #' @family validation methods
 #' @examples
 #' data(latrendData)
-#' trainFolds <- createTrainDataFolds(latrendData, folds = 10, id = "Id")
 #'
-#' trainFolds <- createTrainDataFolds(latrendData, folds = 10, id = "Id", seed = 1)
+#' if (require("caret")) {
+#'   trainFolds <- createTrainDataFolds(latrendData, folds = 10, id = "Id")
+#'
+#'   trainFolds <- createTrainDataFolds(latrendData, folds = 10, id = "Id", seed = 1)
+#' }
 createTrainDataFolds = function(
   data,
   folds = 10,
@@ -756,8 +763,11 @@ createTrainDataFolds = function(
 #' @family validation methods
 #' @examples
 #' data(latrendData)
-#' trainDataList <- createTrainDataFolds(latrendData, id = "Id", folds = 10)
-#' testData1 <- createTestDataFold(latrendData, trainDataList[[1]], id = "Id")
+#'
+#' if (require("caret")) {
+#'   trainDataList <- createTrainDataFolds(latrendData, id = "Id", folds = 10)
+#'   testData1 <- createTestDataFold(latrendData, trainDataList[[1]], id = "Id")
+#' }
 createTestDataFold = function(data, trainData, id = getOption('latrend.id')) {
   assert_that(is.data.frame(trainData))
   trainIds = unique(trainData[[id]])
@@ -777,8 +787,11 @@ createTestDataFold = function(data, trainData, id = getOption('latrend.id')) {
 #' @family validation methods
 #' @examples
 #' data(latrendData)
-#' trainDataList <- createTrainDataFolds(latrendData, folds = 10, id = "Id")
-#' testDataList <- createTestDataFolds(latrendData, trainDataList)
+#'
+#' if (require("caret")) {
+#'   trainDataList <- createTrainDataFolds(latrendData, folds = 10, id = "Id")
+#'   testDataList <- createTestDataFolds(latrendData, trainDataList)
+#' }
 createTestDataFolds = function(data, trainDataList, ...) {
   lapply(trainDataList, function(trainData)
     createTestDataFold(data = data, trainData = trainData, ...))
